@@ -13,8 +13,7 @@ class CommandLineApplication(BrickPiWrapper):
     '''
 
     def __init__(self, sensorConfiguration={}):
-        '''Initialization: *sensorConfiguration* is a map, e.g. {'1': Sensor.ULTRASONIC_CONT}
-        as passed to BrickPiWrapper'''
+        '''Initialization: *sensorConfiguration* is a map as passed to BrickPiWrapper'''
         BrickPiWrapper.__init__(self, sensorConfiguration )
 
     def mainloop(self):
