@@ -19,8 +19,7 @@ class TkApplication(BrickPiWrapper):
     '''
 
     def __init__(self, sensorConfiguration={}):
-        '''Initialization: *sensorConfiguration* is a map, e.g. {'1': Sensor.ULTRASONIC_CONT}
-        as passed to BrickPiWrapper'''
+        '''Initialization: *sensorConfiguration* is a map as passed to BrickPiWrapper'''
         BrickPiWrapper.__init__(self, sensorConfiguration )
         self.root = tk.Tk()
 
